@@ -1,6 +1,6 @@
 import argparse, asyncio, json
-from EventHub import Event
-from Settings import Environment
+import EventHub.Event as Event
+import Settings.Environment as Environment
 
 def run(event_type):
     loop = asyncio.new_event_loop()
